==> iter_columns-0.1.0.crate: iter_columns-0.1.0/src/prelude.rs <==
pub use crate::iter::ColExtIntoIterArray;
pub use crate::iter::ColExtIntoIterVec;
pub use crate::iter::IterColumnsArrayBorrowed10Ext;
pub use crate::iter::IterColumnsArrayBorrowed1Ext;
pub use crate::iter::IterColumnsArrayBorrowed2Ext;
pub use crate::iter::IterColumnsArrayBorrowed3Ext;
pub use crate::iter::IterColumnsArrayBorrowed4Ext;
pub use crate::iter::IterColumnsArrayBorrowed5Ext;
pub use crate::iter::IterColumnsArrayBorrowed6Ext;
pub use crate::iter::IterColumnsArrayBorrowed7Ext;
pub use crate::iter::IterColumnsArrayBorrowed8Ext;
pub use crate::iter::IterColumnsArrayBorrowed9Ext;
pub use crate::iter::IterColumnsSliceBorrowed10Ext;
pub use crate::iter::IterColumnsSliceBorrowed1Ext;
pub use crate::iter::IterColumnsSliceBorrowed2Ext;
pub use crate::iter::IterColumnsSliceBorrowed3Ext;
pub use crate::iter::IterColumnsSliceBorrowed4Ext;
pub use crate::iter::IterColumnsSliceBorrowed5Ext;
pub use crate::iter::IterColumnsSliceBorrowed6Ext;
pub use crate::iter::IterColumnsSliceBorrowed7Ext;
pub use crate::iter::IterColumnsSliceBorrowed8Ext;
pub use crate::iter::IterColumnsSliceBorrowed9Ext;
pub use crate::iter::IterColumnsVecBorrowed10Ext;
pub use crate::iter::IterColumnsVecBorrowed1Ext;
pub use crate::iter::IterColumnsVecBorrowed2Ext;
pub use crate::iter::IterColumnsVecBorrowed3Ext;
pub use crate::iter::IterColumnsVecBorrowed4Ext;
pub use crate::iter::IterColumnsVecBorrowed5Ext;
pub use crate::iter::IterColumnsVecBorrowed6Ext;
pub use crate::iter::IterColumnsVecBorrowed7Ext;
pub use crate::iter::IterColumnsVecBorrowed8Ext;
pub use crate::iter::IterColumnsVecBorrowed9Ext;

==> iter_columns-0.2.0.crate: iter_columns-0.2.0/src/prelude.rs <==
#[cfg(not(feature = "no_array"))]
pub use crate::iter::ColExtIntoIterArray;
pub use crate::iter::ColExtIntoIterVec;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed10Ext;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed1Ext;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed2Ext;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed3Ext;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed4Ext;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed5Ext;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed6Ext;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed7Ext;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed8Ext;
#[cfg(not(feature = "no_array"))]
pub use crate::iter::IterColumnsArrayBorrowed9Ext;
pub use crate::iter::IterColumnsSliceBorrowed10Ext;
pub use crate::iter::IterColumnsSliceBorrowed1Ext;
pub use crate::iter::IterColumnsSliceBorrowed2Ext;
pub use crate::iter::IterColumnsSliceBorrowed3Ext;
pub use crate::iter::IterColumnsSliceBorrowed4Ext;
pub use crate::iter::IterColumnsSliceBorrowed5Ext;
pub use crate::iter::IterColumnsSliceBorrowed6Ext;
pub use crate::iter::IterColumnsSliceBorrowed7Ext;
pub use crate::iter::IterColumnsSliceBorrowed8Ext;
pub use crate::iter::IterColumnsSliceBorrowed9Ext;
pub use crate::iter::IterColumnsVecBorrowed10Ext;
pub use crate::iter::IterColumnsVecBorrowed1Ext;
pub use crate::iter::IterColumnsVecBorrowed2Ext;
pub use crate::iter::IterColumnsVecBorrowed3Ext;
pub use crate::iter::IterColumnsVecBorrowed4Ext;
pub use crate::iter::IterColumnsVecBorrowed5Ext;
pub use crate::iter::IterColumnsVecBorrowed6Ext;
pub use crate::iter::IterColumnsVecBorrowed7Ext;
pub use crate::iter::IterColumnsVecBorrowed8Ext;
pub use crate::iter::IterColumnsVecBorrowed9Ext;
